==> haskell-unbounded-delays-0.1.0.9-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.0.9
id: unbounded-delays-0.1.0.9-CXTixMaSYyFHs5PPXksFYo
key: unbounded-delays-0.1.0.9-CXTixMaSYyFHs5PPXksFYo
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: 5032515e7427114a4b56d5a10fd457b7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.0.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/unbounded-delays-0.1.0.9
hs-libraries: HSunbounded-delays-0.1.0.9-CXTixMaSYyFHs5PPXksFYo
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.0.10-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.0.10
id: unbounded-delays-0.1.0.10-HPxBabkIrqTB5EavY9b0Zk
key: unbounded-delays-0.1.0.10-HPxBabkIrqTB5EavY9b0Zk
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: dece9f81aeb8126dc725aee245e4f6f4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.0.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/unbounded-delays-0.1.0.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/unbounded-delays-0.1.0.10
hs-libraries: HSunbounded-delays-0.1.0.10-HPxBabkIrqTB5EavY9b0Zk
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
